@@ -727,7 +727,7 @@ class TkeClient(AbstractClient):
 
 
     def DeletePrometheusTemplate(self, request):
-        """删除一个云原生Promehtheus配置模板
+        """删除一个云原生Prometheus配置模板
 
         :param request: Request instance for DeletePrometheusTemplate.
         :type request: :class:`tencentcloud.tke.v20180525.models.DeletePrometheusTemplateRequest`
